// KERF AMOUNT
//    Define the amount of space to compensate for your laser's cutting diameter
Kerf = 0.15;    // Kerf 0.2 is generous

// RULER DIMENSIONS TO CREATE
//    I recommend NO LESS than 3/4-inch high for 6-inch wide rulers
//    and NO MORE than 1+1/4-inch high for 12-inch and longer rulers.
W=6; H=3/4;
RulerWidth = in2mm(W); RulerHeight = in2mm(H);

// HORIZONTAL WIDTH OF LINES IN MILLIMETERS
LineWidth = 0.25;

// VERTICAL LENGTH OF MARKS DENOTED IN MILLIMETERS
//    The following index positions indicate the length of the mark:
//    inches       : [1.0000, 0.5000, 0.2500, 0.1250, 0.0625]
//    millimeters  : [n/a,    n/a,    10,     5,      1     ]
Tick = [6,5,4,3,2];

// FONTS TO USE FOR RULE LABELS
inFontStyle = "Arial";
inFontSize = 3;
mmFontStyle = "Arial";
mmFontSize = 2;


// ... MAIN EVENT ...
// HOW TO USE:
// 1. Uncomment ENGRAVE code and comment CUT code, Render (F6),
//    then save the result (engrave.svg)
// 2. Comment ENGRAVE code and uncomment CUT code, Render (F6),
//    and save the result (cut.svg)
// 3. Open engrave.svg in Inkscape. Copy to clipboard.
// 4. Open cut.svg in Inkscape. PASTE IN PLACE the engrave from clipboard.
//    (important that you PiP in order to keep position)
// 5. Go into Inkscape Document Properties (Shift-Ctrl-D), Custom Size,
//    and select "Resize page to drawing or selection"


// ENGRAVE CODE (don't render with CUT code)
//    Set all objects as NO LINE, SOLID FILL in Inkscape
addInchMarks();
addMilliMarks();
addLogo();
addBling();

// CUT CODE (don't render with ENGRAVE code)
//    Set all objects as SOLID LINE, NO FILL in Inkscape
//addCutline();

// EXPERIMENTAL ALTERNATIVE
//    If the Glowforge UI can cope with all the objects being combined
//    and allow manual marking of cut/engrave, forget the above and
//    uncomment to run the following line to do everything for you:
//difference() { addCutline(); addInchMarks(); addMilliMarks(); addLogo(); addBling(); }


// _________________ FUNCTIONS BELOW _________________

// ...Convert inches to millimeters...
function in2mm(inches) = inches * 25.4;

// ...Add the top inch marks to the ruler...
module addInchMarks()
{
    translate( [Kerf, Kerf] )
    {
        for (i = [1:W])
        {
            translate( [in2mm(i), 0] )
                for (j = [0:15])
                {
                    xpos=in2mm(-j / 16);
                    l=j%16==0?Tick[0]:j%8==0?Tick[1]:j%4==0?Tick[2]:j%2==0?Tick[3]:Tick[4]; // Sorry. Not sorry. :)
                    translate( [xpos, RulerHeight-l, 0] ) square( [LineWidth, l] );
                }
            translate( [in2mm(i)-0.5, RulerHeight - Tick[0]] )
                text(str(i), font=inFontStyle, size=inFontSize, halign="right", valign="center");
        }
        // add final details - zero mark, unit label, etc.
        translate( [1, RulerHeight - Tick[0]] )
            text("0", font=inFontStyle, size=inFontSize, halign="left", valign="center");
        translate( [in2mm(1/4), RulerHeight - Tick[0]] )
            text("INCH", inFontStyle, size=1.5, halign="center", valign="top");
        translate( [0, RulerHeight - Tick[0]] )
            square( [LineWidth, Tick[0]] );
    }
}

// ...Add the bottom milli-/centimeter marks to the ruler...
module addMilliMarks()
{
    translate( [Kerf, Kerf] )
    {
        for (i = [1:in2mm(W)] )
        {
            l = i%10==0?Tick[2]:i%5==0?Tick[3]:Tick[4];
            translate( [i, 0] ) square( [LineWidth, l] );
            
            if (!i%10) // Label the tick
                translate( [i - 0.5, Tick[2]] )
                    text(str(i/10), font=mmFontStyle, size=mmFontSize, halign="right", valign="center");
        }
        // add final details - zero mark, unit label, etc.
        translate( [1, Tick[2]] )
            text("0", font=mmFontStyle, size=mmFontSize, halign="left", valign="center");
        translate( [5, Tick[2]] )
            text("CM", mmFontStyle, size=1.5, halign="center");
        translate( [0, 0] )
            square( [LineWidth, Tick[2]] );
    }
}

// ...Load the logo from a DXF file...
//    [0,0] of the DXF is assumed to be the exact center of it for placement.
//    Tweak scale=x.xx to make it larger/smaller
module addLogo()
{
    translate( [Kerf, Kerf] )
    {
        translate( [15 + LineWidth / 2, RulerHeight / 2] ) rotate(90) import(file="logo.dxf", scale=0.05);
    }
}

// ...Render the outline cut...
module addCutline()
{
    square( [RulerWidth + LineWidth + (Kerf * 2), RulerHeight + (Kerf * 2)] );
}

// ...Add some flair...
module addBling()
{
    translate( [Kerf, Kerf] )
    {
        translate( [RulerWidth - 9, (RulerHeight / 2) - 1] )
            text("Dan Berry", font="Rock Salt", size=2.5, halign="right", valign="center");
        translate( [RulerWidth - 8, (RulerHeight / 2) - 1] )
            text("", font="Material Icons", size=4, valign="center");
    }
}
